@@ -55,7 +55,7 @@ tar_make_clustermq <- function(
   tar_assert_package("clustermq")
   tar_assert_scalar(shortcut)
   tar_assert_lgl(shortcut)
-  tar_assert_flag(reporter, tar_make_reporters())
+  tar_assert_flag(reporter, tar_reporters_make())
   tar_assert_scalar(workers)
   tar_assert_dbl(workers)
   tar_assert_ge(workers, 1)
