@@ -31,7 +31,7 @@ tar_test <- function(label, code) {
     )
     withr::local_envvar(c(TAR_ASK = "false", TAR_TEST = "true"))
     tar_option_reset()
-    on.exit(tar_option_reset())
+    on.exit(tar_option_reset(), add = TRUE)
     tar_option_set(envir = new.env(parent = globalenv()))
     suppressMessages(eval(expr, envir = parent.frame()))
   }
