@@ -1,7 +1,7 @@
 tar_test("aws_fst_tbl packages", {
   target <- tar_target(x, "x_value", format = "aws_fst_tbl")
   out <- sort(store_get_packages(target$store))
-  exp <- sort(c("aws.s3", "fst", "tibble"))
+  exp <- sort(c("paws", "fst", "tibble"))
   expect_equal(out, exp)
 })
 
@@ -23,7 +23,7 @@ tar_test("store_path_from_record()", {
 })
 
 tar_test("validate aws_fst_tbl", {
-  skip_if_not_installed("aws.s3")
+  skip_if_not_installed("paws")
   skip_if_not_installed("fst")
   skip_if_not_installed("tibble")
   tar_script(list(tar_target(x, "x_value", format = "aws_fst_tbl")))
