@@ -34,6 +34,18 @@ tar_test("set, get, exists, and unset interactive", {
   expect_null(x$get_interactive())
 })
 
+tar_test("set, get, exists, and unset store", {
+  x <- runtime_init()
+  expect_false(x$exists_store())
+  expect_null(x$get_store())
+  x$set_store("store")
+  expect_true(x$exists_store())
+  expect_equal(x$get_store(), "store")
+  x$unset_store()
+  expect_false(x$exists_store())
+  expect_null(x$get_store())
+})
+
 tar_test("validate null runtime", {
   x <- runtime_init()
   expect_silent(x$validate())
@@ -62,3 +74,20 @@ tar_test("invalidate bad interactive", {
   x <- runtime_init(interactive = letters)
   expect_error(x$validate(), class = "tar_condition_validate")
 })
+
+tar_test("validate null store", {
+  x <- runtime_init()
+  expect_silent(x$validate())
+})
+
+tar_test("validate non-null store", {
+  x <- runtime_init()
+  x$set_store("store")
+  expect_silent(x$validate())
+})
+
+tar_test("detect bad store", {
+  x <- runtime_init()
+  x$set_store(FALSE)
+  expect_error(x$validate(), class = "tar_condition_validate")
+})
