@@ -35,9 +35,9 @@ tar_test("tar_read() on patterns with vector iteration", {
     )
   )
   local_init(pipeline = pipeline)$run()
-  expect_equal(tar_read(y), letters[seq_len(4L)])
+  expect_equal(unname(tar_read(y)), letters[seq_len(4L)])
   out <- tar_read(y, branches = c(2L, 3L))
-  expect_equal(out, letters[c(2L, 3L)])
+  expect_equal(unname(out), letters[c(2L, 3L)])
   expect_error(tar_read(y, branches = 99L), class = "tar_condition_validate")
 })
 
@@ -49,5 +49,34 @@ tar_test("tar_read() on patterns with list iteration", {
     )
   )
   local_init(pipeline = pipeline)$run()
-  expect_equal(tar_read(y), as.list(letters[seq_len(4L)]))
+  expect_equal(unname(tar_read(y)), as.list(letters[seq_len(4L)]))
+})
+
+tar_test("custom script and store args", {
+  skip_on_cran()
+  expect_equal(tar_config_get("script"), path_script_default())
+  expect_equal(tar_config_get("store"), path_store_default())
+  tar_script({
+    list(
+      tar_target(w, letters)
+    )
+  }, script = "example/script.R")
+  tar_make(
+    callr_function = NULL,
+    script = "example/script.R",
+    store = "example/store"
+  )
+  expect_equal(tar_read(w, store = "example/store"), letters)
+  expect_false(file.exists("_targets.yaml"))
+  expect_equal(tar_config_get("script"), path_script_default())
+  expect_equal(tar_config_get("store"), path_store_default())
+  expect_false(file.exists(path_script_default()))
+  expect_false(file.exists(path_store_default()))
+  expect_true(file.exists("example/script.R"))
+  expect_true(file.exists("example/store"))
+  expect_true(file.exists("example/store/meta/meta"))
+  expect_true(file.exists("example/store/objects/w"))
+  tar_config_set(script = "x")
+  expect_equal(tar_config_get("script"), "x")
+  expect_true(file.exists("_targets.yaml"))
 })
